@@ -63,7 +63,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         VCD_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         vcd_parse
 #define yylex           vcd_lex
@@ -74,7 +75,7 @@
 #define yychar          vcd_char
 
 /* First part of user prologue.  */
-#line 3 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
 
 /*
  * parse_vcd.y - parser for a VCD data file
@@ -117,7 +118,7 @@
 #include "check_vcd.h"
 
 
-#line 121 "parse_vcd.cpp"
+#line 122 "parse_vcd.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -501,7 +502,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined VCD_STYPE_IS_TRIVIAL && VCD_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -622,7 +623,7 @@ static const yytype_int8 yytranslate[] =
       55,    56,    57,    58,    59,    60
 };
 
-#if YYDEBUG
+#if VCD_DEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
@@ -640,7 +641,7 @@ static const yytype_int16 yyrline[] =
 /** Accessing symbol of state STATE.  */
 #define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])
 
-#if YYDEBUG || 0
+#if VCD_DEBUG || 0
 /* The user-facing name of the symbol whose (internal) number is
    YYSYMBOL.  No bounds checking.  */
 static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;
@@ -814,7 +815,7 @@ static const yytype_int8 yyr2[] =
 enum { YYENOMEM = -2 };
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (yychar = YYEMPTY)
+#define yyclearin       (yychar = VCD_EMPTY)
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
@@ -826,7 +827,7 @@ enum { YYENOMEM = -2 };
 
 #define YYBACKUP(Token, Value)                                    \
   do                                                              \
-    if (yychar == YYEMPTY)                                        \
+    if (yychar == VCD_EMPTY)                                        \
       {                                                           \
         yychar = (Token);                                         \
         yylval = (Value);                                         \
@@ -842,12 +843,12 @@ enum { YYENOMEM = -2 };
   while (0)
 
 /* Backward compatibility with an undocumented macro.
-   Use YYerror or YYUNDEF. */
-#define YYERRCODE YYUNDEF
+   Use VCD_error or VCD_UNDEF. */
+#define YYERRCODE VCD_UNDEF
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if VCD_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -965,12 +966,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !VCD_DEBUG */
 # define YYDPRINTF(Args) ((void) 0)
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !VCD_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -1070,7 +1071,7 @@ yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = VCD_EMPTY; /* Cause a token to be read.  */
 
   goto yysetstate;
 
@@ -1180,25 +1181,25 @@ yybackup:
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
-  if (yychar == YYEMPTY)
+  if (yychar == VCD_EMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token\n"));
       yychar = yylex ();
     }
 
-  if (yychar <= YYEOF)
+  if (yychar <= VCD_EOF)
     {
-      yychar = YYEOF;
+      yychar = VCD_EOF;
       yytoken = YYSYMBOL_YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
-  else if (yychar == YYerror)
+  else if (yychar == VCD_error)
     {
       /* The scanner already issued an error message, process directly
          to error recovery.  But do not keep the error token as
          lookahead, it is too special and may lead us to an endless
          loop in error recovery. */
-      yychar = YYUNDEF;
+      yychar = VCD_UNDEF;
       yytoken = YYSYMBOL_YYerror;
       goto yyerrlab1;
     }
@@ -1235,7 +1236,7 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  yychar = VCD_EMPTY;
   goto yynewstate;
 
 
@@ -1271,7 +1272,7 @@ yyreduce:
   switch (yyn)
     {
   case 8: /* Declaration: t_SCOPE ScopeDeclaration t_END  */
-#line 119 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 119 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                     {
      if (!vcd->scopes) {
        /* no scope defined yet */
@@ -1288,11 +1289,11 @@ yyreduce:
      }
      vcd->currentscope = (yyvsp[-1].scope);
    }
-#line 1292 "parse_vcd.cpp"
+#line 1293 "parse_vcd.cpp"
     break;
 
   case 10: /* Declaration: t_UPSCOPE t_END  */
-#line 136 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 136 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                      {
      if (vcd->currentscope->parent) {
        /* up one scope */
@@ -1302,11 +1303,11 @@ yyreduce:
 		vcd_lineno);
      }
    }
-#line 1306 "parse_vcd.cpp"
+#line 1307 "parse_vcd.cpp"
     break;
 
   case 12: /* Declaration: t_VAR VarDeclaration t_END  */
-#line 146 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 146 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                 {
      if (!vcd->scopes) {
        /* no scope defined yet */
@@ -1320,114 +1321,114 @@ yyreduce:
      (yyvsp[-1].vardef)->next = vcd->currentscope->vardefs;
      vcd->currentscope->vardefs = (yyvsp[-1].vardef);
    }
-#line 1324 "parse_vcd.cpp"
+#line 1325 "parse_vcd.cpp"
     break;
 
   case 13: /* ScopeDeclaration: ScopeType Identifier  */
-#line 162 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 162 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                         {
      (yyval.scope) = (struct vcd_scope *) calloc (1, sizeof (struct vcd_scope));
      (yyval.scope)->type = (yyvsp[-1].stype);
      (yyval.scope)->ident = (yyvsp[0].ident);
    }
-#line 1334 "parse_vcd.cpp"
+#line 1335 "parse_vcd.cpp"
     break;
 
   case 14: /* ScopeType: s_MODULE  */
-#line 170 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 170 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                 { (yyval.stype) = SCOPE_MODULE;   }
-#line 1340 "parse_vcd.cpp"
+#line 1341 "parse_vcd.cpp"
     break;
 
   case 15: /* ScopeType: s_TASK  */
-#line 171 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 171 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                 { (yyval.stype) = SCOPE_TASK;     }
-#line 1346 "parse_vcd.cpp"
+#line 1347 "parse_vcd.cpp"
     break;
 
   case 16: /* ScopeType: s_FUNCTION  */
-#line 172 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 172 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                 { (yyval.stype) = SCOPE_FUNCTION; }
-#line 1352 "parse_vcd.cpp"
+#line 1353 "parse_vcd.cpp"
     break;
 
   case 17: /* ScopeType: s_BEGIN  */
-#line 173 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 173 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                 { (yyval.stype) = SCOPE_BEGIN;    }
-#line 1358 "parse_vcd.cpp"
+#line 1359 "parse_vcd.cpp"
     break;
 
   case 18: /* ScopeType: s_FORK  */
-#line 174 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 174 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                 { (yyval.stype) = SCOPE_FORK;     }
-#line 1364 "parse_vcd.cpp"
+#line 1365 "parse_vcd.cpp"
     break;
 
   case 19: /* TimeScaleDeclaration: TimeScale TimeUnit  */
-#line 178 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 178 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                       {
      vcd->t = (yyvsp[-1].integer);
      vcd->scale = (yyvsp[0].real);
    }
-#line 1373 "parse_vcd.cpp"
+#line 1374 "parse_vcd.cpp"
     break;
 
   case 20: /* TimeScale: ONE  */
-#line 185 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 185 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
              { (yyval.integer) = 1;   }
-#line 1379 "parse_vcd.cpp"
+#line 1380 "parse_vcd.cpp"
     break;
 
   case 21: /* TimeScale: TEN  */
-#line 186 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 186 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
              { (yyval.integer) = 10;  }
-#line 1385 "parse_vcd.cpp"
+#line 1386 "parse_vcd.cpp"
     break;
 
   case 22: /* TimeScale: HUNDRET  */
-#line 187 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 187 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
              { (yyval.integer) = 100; }
-#line 1391 "parse_vcd.cpp"
+#line 1392 "parse_vcd.cpp"
     break;
 
   case 23: /* TimeUnit: SECOND  */
-#line 191 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 191 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.real) = 1;     }
-#line 1397 "parse_vcd.cpp"
+#line 1398 "parse_vcd.cpp"
     break;
 
   case 24: /* TimeUnit: MILLI  */
-#line 192 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 192 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.real) = 1e-3;  }
-#line 1403 "parse_vcd.cpp"
+#line 1404 "parse_vcd.cpp"
     break;
 
   case 25: /* TimeUnit: MICRO  */
-#line 193 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 193 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.real) = 1e-6;  }
-#line 1409 "parse_vcd.cpp"
+#line 1410 "parse_vcd.cpp"
     break;
 
   case 26: /* TimeUnit: NANO  */
-#line 194 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 194 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.real) = 1e-9;  }
-#line 1415 "parse_vcd.cpp"
+#line 1416 "parse_vcd.cpp"
     break;
 
   case 27: /* TimeUnit: PICO  */
-#line 195 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 195 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.real) = 1e-12; }
-#line 1421 "parse_vcd.cpp"
+#line 1422 "parse_vcd.cpp"
     break;
 
   case 28: /* TimeUnit: FEMTO  */
-#line 196 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 196 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
             { (yyval.real) = 1e-15; }
-#line 1427 "parse_vcd.cpp"
+#line 1428 "parse_vcd.cpp"
     break;
 
   case 29: /* VarDeclaration: VarType Size IdentifierCode Reference BitSelect  */
-#line 200 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 200 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                                    {
      (yyval.vardef) = (struct vcd_vardef *) calloc (1, sizeof (struct vcd_vardef));
      (yyval.vardef)->type = (yyvsp[-4].vtype);
@@ -1436,247 +1437,247 @@ yyreduce:
      (yyval.vardef)->ident = (yyvsp[-1].ident);
      (yyval.vardef)->range = (yyvsp[0].range);
    }
-#line 1440 "parse_vcd.cpp"
+#line 1441 "parse_vcd.cpp"
     break;
 
   case 30: /* BitSelect: %empty  */
-#line 210 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 210 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                          { (yyval.range) = NULL; }
-#line 1446 "parse_vcd.cpp"
+#line 1447 "parse_vcd.cpp"
     break;
 
   case 31: /* BitSelect: '[' PositiveInteger ']'  */
-#line 211 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 211 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                               {
       (yyval.range) = (struct vcd_range *) calloc (1, sizeof (struct vcd_range));
       (yyval.range)->l = -1;
       (yyval.range)->h = (yyvsp[-1].integer);
     }
-#line 1456 "parse_vcd.cpp"
+#line 1457 "parse_vcd.cpp"
     break;
 
   case 32: /* BitSelect: '[' PositiveInteger ':' PositiveInteger ']'  */
-#line 216 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 216 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                                   {
       (yyval.range) = (struct vcd_range *) calloc (1, sizeof (struct vcd_range));
       (yyval.range)->l = (yyvsp[-3].integer);
       (yyval.range)->h = (yyvsp[-1].integer);
     }
-#line 1466 "parse_vcd.cpp"
+#line 1467 "parse_vcd.cpp"
     break;
 
   case 33: /* BitSelect: '(' PositiveInteger ')'  */
-#line 221 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 221 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                               {
       (yyval.range) = (struct vcd_range *) calloc (1, sizeof (struct vcd_range));
       (yyval.range)->l = (yyvsp[-1].integer);
       (yyval.range)->h = -1;
     }
-#line 1476 "parse_vcd.cpp"
+#line 1477 "parse_vcd.cpp"
     break;
 
   case 34: /* VarType: EVENT  */
-#line 229 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 229 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_EVENT;
      /* a special type to synchronize different statement blocks */ }
-#line 1483 "parse_vcd.cpp"
+#line 1484 "parse_vcd.cpp"
     break;
 
   case 35: /* VarType: INTEGER  */
-#line 231 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 231 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_INTEGER;
      /* signed 32-bit variable */ }
-#line 1490 "parse_vcd.cpp"
+#line 1491 "parse_vcd.cpp"
     break;
 
   case 36: /* VarType: PARAMETER  */
-#line 233 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 233 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_PARAMETER;
      /* a named constant - the default value of a parameter can be
 	overwritten, when declaring an instance of the associated module */ }
-#line 1498 "parse_vcd.cpp"
+#line 1499 "parse_vcd.cpp"
     break;
 
   case 37: /* VarType: REAL  */
-#line 236 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 236 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_REAL;
      /* double-precision floating point */ }
-#line 1505 "parse_vcd.cpp"
+#line 1506 "parse_vcd.cpp"
     break;
 
   case 38: /* VarType: REG  */
-#line 238 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 238 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_REG;
      /* unsigned variable of any bit size */ }
-#line 1512 "parse_vcd.cpp"
+#line 1513 "parse_vcd.cpp"
     break;
 
   case 39: /* VarType: SUPPLY0  */
-#line 240 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 240 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_SUPPLY0;
      /* constant logic 0 (supply strength) */ }
-#line 1519 "parse_vcd.cpp"
+#line 1520 "parse_vcd.cpp"
     break;
 
   case 40: /* VarType: SUPPLY1  */
-#line 242 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 242 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_SUPPLY1;
      /* constant logic 1 (supply strength) */ }
-#line 1526 "parse_vcd.cpp"
+#line 1527 "parse_vcd.cpp"
     break;
 
   case 41: /* VarType: TIME  */
-#line 244 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 244 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TIME;
      /* unsigned 64-bit variable */ }
-#line 1533 "parse_vcd.cpp"
+#line 1534 "parse_vcd.cpp"
     break;
 
   case 42: /* VarType: TRI  */
-#line 246 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 246 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TRI;
      /* simple interconnecting wire */ }
-#line 1540 "parse_vcd.cpp"
+#line 1541 "parse_vcd.cpp"
     break;
 
   case 43: /* VarType: TRIAND  */
-#line 248 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 248 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TRIAND;
      /* wired outputs AND together */ }
-#line 1547 "parse_vcd.cpp"
+#line 1548 "parse_vcd.cpp"
     break;
 
   case 44: /* VarType: TRIOR  */
-#line 250 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 250 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TRIOR;
      /* wired outputs OR together */ }
-#line 1554 "parse_vcd.cpp"
+#line 1555 "parse_vcd.cpp"
     break;
 
   case 45: /* VarType: TRIREG  */
-#line 252 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 252 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TRIREG;
      /* stores last value when tri-stated (capacitance strength) */ }
-#line 1561 "parse_vcd.cpp"
+#line 1562 "parse_vcd.cpp"
     break;
 
   case 46: /* VarType: TRI0  */
-#line 254 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 254 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TRI0;
      /* pulls down when tri-stated */ }
-#line 1568 "parse_vcd.cpp"
+#line 1569 "parse_vcd.cpp"
     break;
 
   case 47: /* VarType: TRI1  */
-#line 256 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 256 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_TRI1;
      /* pulls up when tri-stated */ }
-#line 1575 "parse_vcd.cpp"
+#line 1576 "parse_vcd.cpp"
     break;
 
   case 48: /* VarType: WAND  */
-#line 258 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 258 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_WAND;
      /* wired outputs AND together */ }
-#line 1582 "parse_vcd.cpp"
+#line 1583 "parse_vcd.cpp"
     break;
 
   case 49: /* VarType: WIRE  */
-#line 260 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 260 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_WIRE;
      /* simple interconnecting wire */ }
-#line 1589 "parse_vcd.cpp"
+#line 1590 "parse_vcd.cpp"
     break;
 
   case 50: /* VarType: WOR  */
-#line 262 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 262 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                { (yyval.vtype) = VAR_WOR;
      /* wired outputs OR together */ }
-#line 1596 "parse_vcd.cpp"
+#line 1597 "parse_vcd.cpp"
     break;
 
   case 57: /* SimulationCommand: t_DUMPVARS ValueChangeList t_END  */
-#line 278 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 278 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                      {
       vcd->changesets->changes = (yyvsp[-1].change);
   }
-#line 1604 "parse_vcd.cpp"
+#line 1605 "parse_vcd.cpp"
     break;
 
   case 58: /* SimulationCommand: ValueChangeset  */
-#line 281 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 281 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                    {
       (yyvsp[0].changeset)->next = vcd->changesets;
       vcd->changesets = (yyvsp[0].changeset);
   }
-#line 1613 "parse_vcd.cpp"
+#line 1614 "parse_vcd.cpp"
     break;
 
   case 59: /* ValueChangeset: SimulationTime ValueChangeList  */
-#line 288 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 288 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                    {
       (yyval.changeset) = (struct vcd_changeset *) calloc (1, sizeof (struct vcd_changeset));
       (yyval.changeset)->t = (yyvsp[-1].real);
       (yyval.changeset)->changes = (yyvsp[0].change);
     }
-#line 1623 "parse_vcd.cpp"
+#line 1624 "parse_vcd.cpp"
     break;
 
   case 60: /* SimulationTime: HASHMARK PositiveHugeInteger  */
-#line 296 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 296 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                  {
       (yyval.real) = (yyvsp[0].real);
     }
-#line 1631 "parse_vcd.cpp"
+#line 1632 "parse_vcd.cpp"
     break;
 
   case 61: /* ValueChangeList: %empty  */
-#line 301 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 301 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                { (yyval.change) = NULL; }
-#line 1637 "parse_vcd.cpp"
+#line 1638 "parse_vcd.cpp"
     break;
 
   case 62: /* ValueChangeList: ValueChange ValueChangeList  */
-#line 302 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 302 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                                   {
       (yyvsp[-1].change)->next = (yyvsp[0].change);
     }
-#line 1645 "parse_vcd.cpp"
+#line 1646 "parse_vcd.cpp"
     break;
 
   case 65: /* ScalarValueChange: Value IdentifierCode  */
-#line 313 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 313 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                          {
       (yyval.change) = (struct vcd_change *) calloc (1, sizeof (struct vcd_change));
       (yyval.change)->value = (yyvsp[-1].value);
       (yyval.change)->code = (yyvsp[0].ident);
     }
-#line 1655 "parse_vcd.cpp"
+#line 1656 "parse_vcd.cpp"
     break;
 
   case 70: /* VectorValueChange: 'B' Binary IdentifierCode  */
-#line 328 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 328 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                               {
       (yyval.change) = (struct vcd_change *) calloc (1, sizeof (struct vcd_change));
       (yyval.change)->value = (yyvsp[-1].value);
       (yyval.change)->code = (yyvsp[0].ident);
     }
-#line 1665 "parse_vcd.cpp"
+#line 1666 "parse_vcd.cpp"
     break;
 
   case 71: /* VectorValueChange: 'R' Real IdentifierCode  */
-#line 333 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 333 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
                               {
       (yyval.change) = (struct vcd_change *) calloc (1, sizeof (struct vcd_change));
       (yyval.change)->value = (yyvsp[-1].value);
       (yyval.change)->code = (yyvsp[0].ident);
       (yyval.change)->isreal = 1;
     }
-#line 1676 "parse_vcd.cpp"
+#line 1677 "parse_vcd.cpp"
     break;
 
 
-#line 1680 "parse_vcd.cpp"
+#line 1681 "parse_vcd.cpp"
 
       default: break;
     }
@@ -1718,7 +1719,7 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
+  yytoken = yychar == VCD_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
@@ -1731,17 +1732,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (yychar <= YYEOF)
+      if (yychar <= VCD_EOF)
         {
           /* Return failure if at end of input.  */
-          if (yychar == YYEOF)
+          if (yychar == VCD_EOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
                       yytoken, &yylval);
-          yychar = YYEMPTY;
+          yychar = VCD_EMPTY;
         }
     }
 
@@ -1843,7 +1844,7 @@ yyexhaustedlab:
 | yyreturnlab -- parsing is finished, clean up and return.  |
 `----------------------------------------------------------*/
 yyreturnlab:
-  if (yychar != YYEMPTY)
+  if (yychar != VCD_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
@@ -1869,7 +1870,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 342 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_vcd.ypp"
+#line 342 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_vcd.ypp"
 
 
 int vcd_error (const char * error) {
