@@ -63,7 +63,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         CITI_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         citi_parse
 #define yylex           citi_lex
@@ -74,7 +75,7 @@
 #define yychar          citi_char
 
 /* First part of user prologue.  */
-#line 3 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
 
 /*
  * parse_citi.y - parser for CITIfiles
@@ -123,7 +124,7 @@
 using namespace qucs;
 
 
-#line 127 "parse_citi.cpp"
+#line 128 "parse_citi.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -456,7 +457,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined CITI_STYPE_IS_TRIVIAL && CITI_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -573,7 +574,7 @@ static const yytype_int8 yytranslate[] =
       15,    16,    17,    18,    19,    20,    21,    22
 };
 
-#if YYDEBUG
+#if CITI_DEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
@@ -586,7 +587,7 @@ static const yytype_uint8 yyrline[] =
 /** Accessing symbol of state STATE.  */
 #define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])
 
-#if YYDEBUG || 0
+#if CITI_DEBUG || 0
 /* The user-facing name of the symbol whose (internal) number is
    YYSYMBOL.  No bounds checking.  */
 static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;
@@ -725,7 +726,7 @@ static const yytype_int8 yyr2[] =
 enum { YYENOMEM = -2 };
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (yychar = YYEMPTY)
+#define yyclearin       (yychar = CITI_EMPTY)
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
@@ -737,7 +738,7 @@ enum { YYENOMEM = -2 };
 
 #define YYBACKUP(Token, Value)                                    \
   do                                                              \
-    if (yychar == YYEMPTY)                                        \
+    if (yychar == CITI_EMPTY)                                        \
       {                                                           \
         yychar = (Token);                                         \
         yylval = (Value);                                         \
@@ -753,12 +754,12 @@ enum { YYENOMEM = -2 };
   while (0)
 
 /* Backward compatibility with an undocumented macro.
-   Use YYerror or YYUNDEF. */
-#define YYERRCODE YYUNDEF
+   Use CITI_error or CITI_UNDEF. */
+#define YYERRCODE CITI_UNDEF
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if CITI_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -876,12 +877,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !CITI_DEBUG */
 # define YYDPRINTF(Args) ((void) 0)
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !CITI_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -981,7 +982,7 @@ yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = CITI_EMPTY; /* Cause a token to be read.  */
 
   goto yysetstate;
 
@@ -1091,25 +1092,25 @@ yybackup:
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
-  if (yychar == YYEMPTY)
+  if (yychar == CITI_EMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token\n"));
       yychar = yylex ();
     }
 
-  if (yychar <= YYEOF)
+  if (yychar <= CITI_EOF)
     {
-      yychar = YYEOF;
+      yychar = CITI_EOF;
       yytoken = YYSYMBOL_YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
-  else if (yychar == YYerror)
+  else if (yychar == CITI_error)
     {
       /* The scanner already issued an error message, process directly
          to error recovery.  But do not keep the error token as
          lookahead, it is too special and may lead us to an endless
          loop in error recovery. */
-      yychar = YYUNDEF;
+      yychar = CITI_UNDEF;
       yytoken = YYSYMBOL_YYerror;
       goto yyerrlab1;
     }
@@ -1146,7 +1147,7 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  yychar = CITI_EMPTY;
   goto yynewstate;
 
 
@@ -1182,21 +1183,21 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* Input: PackageList  */
-#line 94 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 94 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
               {
     citi_root = (yyvsp[0].p); /* describes a valid CITIfile */
   }
-#line 1190 "parse_citi.cpp"
+#line 1191 "parse_citi.cpp"
     break;
 
   case 3: /* PackageList: %empty  */
-#line 99 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 99 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                            { (yyval.p) = NULL; }
-#line 1196 "parse_citi.cpp"
+#line 1197 "parse_citi.cpp"
     break;
 
   case 4: /* PackageList: Package PackageList  */
-#line 100 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 100 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                         {
     if ((yyvsp[-1].p)) {
       (yyvsp[-1].p)->next = (yyvsp[0].p);
@@ -1205,43 +1206,43 @@ yyreduce:
       (yyval.p) = (yyvsp[0].p);
     }
   }
-#line 1209 "parse_citi.cpp"
+#line 1210 "parse_citi.cpp"
     break;
 
   case 5: /* PackageList: Eol PackageList  */
-#line 108 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 108 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                     {
     (yyval.p) = (yyvsp[0].p);
   }
-#line 1217 "parse_citi.cpp"
+#line 1218 "parse_citi.cpp"
     break;
 
   case 6: /* Package: Header DataList  */
-#line 114 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 114 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                   {
     (yyval.p) = (struct citi_package_t *) calloc (sizeof (struct citi_package_t), 1);
     (yyval.p)->head = (yyvsp[-1].h);
     (yyval.p)->data = (yyvsp[0].v);
   }
-#line 1227 "parse_citi.cpp"
+#line 1228 "parse_citi.cpp"
     break;
 
   case 7: /* Header: CITIFILE Version Eol HeaderList  */
-#line 122 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 122 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                   {
     (yyval.h) = (yyvsp[0].h);
   }
-#line 1235 "parse_citi.cpp"
+#line 1236 "parse_citi.cpp"
     break;
 
   case 8: /* HeaderList: %empty  */
-#line 127 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 127 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
             { (yyval.h) = NULL; }
-#line 1241 "parse_citi.cpp"
+#line 1242 "parse_citi.cpp"
     break;
 
   case 9: /* HeaderList: HeaderLine HeaderList  */
-#line 128 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 128 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                           {
     if ((yyvsp[-1].h)) {
       (yyvsp[-1].h)->next = (yyvsp[0].h);
@@ -1250,20 +1251,20 @@ yyreduce:
       (yyval.h) = (yyvsp[0].h);
     }
   }
-#line 1254 "parse_citi.cpp"
+#line 1255 "parse_citi.cpp"
     break;
 
   case 10: /* HeaderLine: NAME Identifier Eol  */
-#line 139 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 139 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                       {
     (yyval.h) = (struct citi_header_t *) calloc (sizeof (struct citi_header_t), 1);
     (yyval.h)->package = (yyvsp[-1].ident);
   }
-#line 1263 "parse_citi.cpp"
+#line 1264 "parse_citi.cpp"
     break;
 
   case 11: /* HeaderLine: VAR Identifier VarType Integer Eol  */
-#line 143 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 143 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                        {
     (yyval.h) = (struct citi_header_t *) calloc (sizeof (struct citi_header_t), 1);
     (yyval.h)->var = (yyvsp[-3].ident);
@@ -1271,22 +1272,22 @@ yyreduce:
     (yyval.h)->n = (yyvsp[-1].d);
     (yyval.h)->i1 = (yyval.h)->i2 = -1;
   }
-#line 1275 "parse_citi.cpp"
+#line 1276 "parse_citi.cpp"
     break;
 
   case 12: /* HeaderLine: DATA Identifier VarType Eol  */
-#line 150 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 150 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                 {
     (yyval.h) = (struct citi_header_t *) calloc (sizeof (struct citi_header_t), 1);
     (yyval.h)->var = (yyvsp[-2].ident);
     (yyval.h)->type = (yyvsp[-1].ident);
     (yyval.h)->n = (yyval.h)->i1 = (yyval.h)->i2 = -1;
   }
-#line 1286 "parse_citi.cpp"
+#line 1287 "parse_citi.cpp"
     break;
 
   case 13: /* HeaderLine: DATA Identifier '[' Integer ',' Integer ']' VarType Eol  */
-#line 156 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 156 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                                             {
     (yyval.h) = (struct citi_header_t *) calloc (sizeof (struct citi_header_t), 1);
     (yyval.h)->var = (yyvsp[-7].ident);
@@ -1295,11 +1296,11 @@ yyreduce:
     (yyval.h)->type = (yyvsp[-1].ident);
     (yyval.h)->n = -1;
   }
-#line 1299 "parse_citi.cpp"
+#line 1300 "parse_citi.cpp"
     break;
 
   case 14: /* HeaderLine: DATA Identifier '[' Integer ']' VarType Eol  */
-#line 164 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 164 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                                 {
     (yyval.h) = (struct citi_header_t *) calloc (sizeof (struct citi_header_t), 1);
     (yyval.h)->var = (yyvsp[-5].ident);
@@ -1307,54 +1308,54 @@ yyreduce:
     (yyval.h)->type = (yyvsp[-1].ident);
     (yyval.h)->n = (yyval.h)->i2 = -1;
   }
-#line 1311 "parse_citi.cpp"
+#line 1312 "parse_citi.cpp"
     break;
 
   case 15: /* HeaderLine: CONSTANT Identifier Float ValueList Eol  */
-#line 171 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 171 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                             {
     /* ignore constants */
   }
-#line 1319 "parse_citi.cpp"
+#line 1320 "parse_citi.cpp"
     break;
 
   case 16: /* ValueList: %empty  */
-#line 176 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 176 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                          { }
-#line 1325 "parse_citi.cpp"
+#line 1326 "parse_citi.cpp"
     break;
 
   case 17: /* ValueList: Float ValueList  */
-#line 177 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 177 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                     {
   }
-#line 1332 "parse_citi.cpp"
+#line 1333 "parse_citi.cpp"
     break;
 
   case 18: /* List: SegListBegin Eol SEG Float Float Float Eol SegListEnd Eol  */
-#line 182 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 182 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                                             {
     (yyval.v) = new vector (qucs::linspace ((yyvsp[-4].f), (yyvsp[-5].f), (int) (yyvsp[-3].f)));
   }
-#line 1340 "parse_citi.cpp"
+#line 1341 "parse_citi.cpp"
     break;
 
   case 19: /* List: VarListBegin Eol VarList VarListEnd Eol  */
-#line 185 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 185 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                             {
     (yyval.v) = (yyvsp[-2].v);
   }
-#line 1348 "parse_citi.cpp"
+#line 1349 "parse_citi.cpp"
     break;
 
   case 20: /* DataList: %empty  */
-#line 190 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 190 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
           { (yyval.v) = NULL; }
-#line 1354 "parse_citi.cpp"
+#line 1355 "parse_citi.cpp"
     break;
 
   case 21: /* DataList: Data DataList  */
-#line 191 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 191 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                   {
     if ((yyvsp[-1].v)) {
       (yyvsp[-1].v)->setNext ((yyvsp[0].v));
@@ -1363,66 +1364,66 @@ yyreduce:
       (yyval.v) = (yyvsp[0].v);
     }
   }
-#line 1367 "parse_citi.cpp"
+#line 1368 "parse_citi.cpp"
     break;
 
   case 22: /* Data: Begin Eol FloatList End Eol  */
-#line 202 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 202 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                               {
     (yyval.v) = (yyvsp[-2].v);
   }
-#line 1375 "parse_citi.cpp"
+#line 1376 "parse_citi.cpp"
     break;
 
   case 23: /* Data: List  */
-#line 205 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 205 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
          {
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1383 "parse_citi.cpp"
+#line 1384 "parse_citi.cpp"
     break;
 
   case 24: /* FloatList: %empty  */
-#line 210 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 210 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
            { (yyval.v) = new vector (); }
-#line 1389 "parse_citi.cpp"
+#line 1390 "parse_citi.cpp"
     break;
 
   case 25: /* FloatList: Float Eol FloatList  */
-#line 211 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 211 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                         {
     (yyvsp[0].v)->add ((yyvsp[-2].f));
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1398 "parse_citi.cpp"
+#line 1399 "parse_citi.cpp"
     break;
 
   case 26: /* FloatList: Float ',' Float Eol FloatList  */
-#line 215 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 215 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                                   {
     (yyvsp[0].v)->add (nr_complex_t ((yyvsp[-4].f), (yyvsp[-2].f)));
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1407 "parse_citi.cpp"
+#line 1408 "parse_citi.cpp"
     break;
 
   case 27: /* VarList: %empty  */
-#line 221 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 221 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
          { (yyval.v) = new vector (); }
-#line 1413 "parse_citi.cpp"
+#line 1414 "parse_citi.cpp"
     break;
 
   case 28: /* VarList: Float Eol VarList  */
-#line 222 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 222 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
                       {
     (yyvsp[0].v)->add ((yyvsp[-2].f));
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1422 "parse_citi.cpp"
+#line 1423 "parse_citi.cpp"
     break;
 
 
-#line 1426 "parse_citi.cpp"
+#line 1427 "parse_citi.cpp"
 
       default: break;
     }
@@ -1464,7 +1465,7 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
+  yytoken = yychar == CITI_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
@@ -1477,17 +1478,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (yychar <= YYEOF)
+      if (yychar <= CITI_EOF)
         {
           /* Return failure if at end of input.  */
-          if (yychar == YYEOF)
+          if (yychar == CITI_EOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
                       yytoken, &yylval);
-          yychar = YYEMPTY;
+          yychar = CITI_EMPTY;
         }
     }
 
@@ -1589,7 +1590,7 @@ yyexhaustedlab:
 | yyreturnlab -- parsing is finished, clean up and return.  |
 `----------------------------------------------------------*/
 yyreturnlab:
-  if (yychar != YYEMPTY)
+  if (yychar != CITI_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
@@ -1615,7 +1616,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 228 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_citi.ypp"
+#line 228 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_citi.ypp"
 
 
 int citi_error (const char * error) {
