@@ -63,7 +63,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         CSV_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         csv_parse
 #define yylex           csv_lex
@@ -74,7 +75,7 @@
 #define yychar          csv_char
 
 /* First part of user prologue.  */
-#line 3 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
 
 /*
  * parse_csv.y - parser for CSV files
@@ -123,7 +124,7 @@
 using namespace qucs;
 
 
-#line 127 "parse_csv.cpp"
+#line 128 "parse_csv.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -433,7 +434,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined CSV_STYPE_IS_TRIVIAL && CSV_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -549,7 +550,7 @@ static const yytype_int8 yytranslate[] =
        5,     6
 };
 
-#if YYDEBUG
+#if CSV_DEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int8 yyrline[] =
 {
@@ -561,7 +562,7 @@ static const yytype_int8 yyrline[] =
 /** Accessing symbol of state STATE.  */
 #define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])
 
-#if YYDEBUG || 0
+#if CSV_DEBUG || 0
 /* The user-facing name of the symbol whose (internal) number is
    YYSYMBOL.  No bounds checking.  */
 static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;
@@ -667,7 +668,7 @@ static const yytype_int8 yyr2[] =
 enum { YYENOMEM = -2 };
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (yychar = YYEMPTY)
+#define yyclearin       (yychar = CSV_EMPTY)
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
@@ -679,7 +680,7 @@ enum { YYENOMEM = -2 };
 
 #define YYBACKUP(Token, Value)                                    \
   do                                                              \
-    if (yychar == YYEMPTY)                                        \
+    if (yychar == CSV_EMPTY)                                        \
       {                                                           \
         yychar = (Token);                                         \
         yylval = (Value);                                         \
@@ -695,12 +696,12 @@ enum { YYENOMEM = -2 };
   while (0)
 
 /* Backward compatibility with an undocumented macro.
-   Use YYerror or YYUNDEF. */
-#define YYERRCODE YYUNDEF
+   Use CSV_error or CSV_UNDEF. */
+#define YYERRCODE CSV_UNDEF
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if CSV_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -818,12 +819,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !CSV_DEBUG */
 # define YYDPRINTF(Args) ((void) 0)
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !CSV_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -923,7 +924,7 @@ yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = CSV_EMPTY; /* Cause a token to be read.  */
 
   goto yysetstate;
 
@@ -1033,25 +1034,25 @@ yybackup:
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
-  if (yychar == YYEMPTY)
+  if (yychar == CSV_EMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token\n"));
       yychar = yylex ();
     }
 
-  if (yychar <= YYEOF)
+  if (yychar <= CSV_EOF)
     {
-      yychar = YYEOF;
+      yychar = CSV_EOF;
       yytoken = YYSYMBOL_YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
-  else if (yychar == YYerror)
+  else if (yychar == CSV_error)
     {
       /* The scanner already issued an error message, process directly
          to error recovery.  But do not keep the error token as
          lookahead, it is too special and may lead us to an endless
          loop in error recovery. */
-      yychar = YYUNDEF;
+      yychar = CSV_UNDEF;
       yytoken = YYSYMBOL_YYerror;
       goto yyerrlab1;
     }
@@ -1088,7 +1089,7 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  yychar = CSV_EMPTY;
   goto yynewstate;
 
 
@@ -1124,120 +1125,120 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* Input: HeaderLine DataSet  */
-#line 74 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 74 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                        { /* describes a valid csv */
     csv_header = (yyvsp[-1].list);
     csv_vector = (yyvsp[0].v);
   }
-#line 1133 "parse_csv.cpp"
+#line 1134 "parse_csv.cpp"
     break;
 
   case 3: /* Input: DataSet  */
-#line 78 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 78 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
             {
     csv_vector = (yyvsp[0].v);
   }
-#line 1141 "parse_csv.cpp"
+#line 1142 "parse_csv.cpp"
     break;
 
   case 4: /* Header: '"' Identifier '"'  */
-#line 84 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 84 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                        {
     (yyval.ident) = strdup ((yyvsp[-1].ident));
   }
-#line 1149 "parse_csv.cpp"
+#line 1150 "parse_csv.cpp"
     break;
 
   case 5: /* Header: Identifier  */
-#line 87 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 87 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                {
     (yyval.ident) = strdup ((yyvsp[0].ident));
   }
-#line 1157 "parse_csv.cpp"
+#line 1158 "parse_csv.cpp"
     break;
 
   case 6: /* HeaderList: %empty  */
-#line 92 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 92 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                           { (yyval.list) = NULL; }
-#line 1163 "parse_csv.cpp"
+#line 1164 "parse_csv.cpp"
     break;
 
   case 7: /* HeaderList: Header HeaderList  */
-#line 93 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 93 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                       {
     if ((yyvsp[0].list) == NULL) (yyvsp[0].list) = new strlist ();
     (yyvsp[0].list)->add ((yyvsp[-1].ident));
     (yyval.list) = (yyvsp[0].list);
     free ((yyvsp[-1].ident));
   }
-#line 1174 "parse_csv.cpp"
+#line 1175 "parse_csv.cpp"
     break;
 
   case 8: /* HeaderLine: HeaderList Eol  */
-#line 102 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 102 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                    {
     (yyval.list) = (yyvsp[-1].list);
   }
-#line 1182 "parse_csv.cpp"
+#line 1183 "parse_csv.cpp"
     break;
 
   case 9: /* HeaderLine: Eol HeaderLine  */
-#line 105 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 105 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                    { /* skip this line */
     (yyval.list) = (yyvsp[0].list);
   }
-#line 1190 "parse_csv.cpp"
+#line 1191 "parse_csv.cpp"
     break;
 
   case 10: /* DataSet: %empty  */
-#line 110 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 110 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                        { (yyval.v) = NULL; }
-#line 1196 "parse_csv.cpp"
+#line 1197 "parse_csv.cpp"
     break;
 
   case 11: /* DataSet: DataLine Eol DataSet  */
-#line 111 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 111 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                          { /* append vector lines */
     (yyvsp[-2].v)->setNext ((yyvsp[0].v));
     (yyval.v) = (yyvsp[-2].v);
   }
-#line 1205 "parse_csv.cpp"
+#line 1206 "parse_csv.cpp"
     break;
 
   case 12: /* DataSet: DataLine  */
-#line 115 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 115 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
              { /* last line, no trailing end-of-line */
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1213 "parse_csv.cpp"
+#line 1214 "parse_csv.cpp"
     break;
 
   case 13: /* DataSet: Eol DataSet  */
-#line 118 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 118 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                 { /* skip this line */
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1221 "parse_csv.cpp"
+#line 1222 "parse_csv.cpp"
     break;
 
   case 15: /* DataList: %empty  */
-#line 126 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 126 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                         { (yyval.v) = NULL; }
-#line 1227 "parse_csv.cpp"
+#line 1228 "parse_csv.cpp"
     break;
 
   case 16: /* DataList: Float DataList  */
-#line 127 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 127 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
                    {
     if ((yyvsp[0].v) == NULL) (yyvsp[0].v) = new vector ();
     (yyvsp[0].v)->add ((yyvsp[-1].f));
     (yyval.v) = (yyvsp[0].v);
   }
-#line 1237 "parse_csv.cpp"
+#line 1238 "parse_csv.cpp"
     break;
 
 
-#line 1241 "parse_csv.cpp"
+#line 1242 "parse_csv.cpp"
 
       default: break;
     }
@@ -1279,7 +1280,7 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
+  yytoken = yychar == CSV_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
@@ -1292,17 +1293,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (yychar <= YYEOF)
+      if (yychar <= CSV_EOF)
         {
           /* Return failure if at end of input.  */
-          if (yychar == YYEOF)
+          if (yychar == CSV_EOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
                       yytoken, &yylval);
-          yychar = YYEMPTY;
+          yychar = CSV_EMPTY;
         }
     }
 
@@ -1404,7 +1405,7 @@ yyexhaustedlab:
 | yyreturnlab -- parsing is finished, clean up and return.  |
 `----------------------------------------------------------*/
 yyreturnlab:
-  if (yychar != YYEMPTY)
+  if (yychar != CSV_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
@@ -1430,7 +1431,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 134 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_csv.ypp"
+#line 134 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_csv.ypp"
 
 
 int csv_error (const char * error) {
