@@ -63,7 +63,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         DATASET_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         dataset_parse
 #define yylex           dataset_lex
@@ -74,7 +75,7 @@
 #define yychar          dataset_char
 
 /* First part of user prologue.  */
-#line 3 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
 
 /*
  * parse_dataset.y - parser for the Qucs dataset
@@ -123,7 +124,7 @@
 using namespace qucs;
 
 
-#line 127 "parse_dataset.cpp"
+#line 128 "parse_dataset.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -441,7 +442,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined DATASET_STYPE_IS_TRIVIAL && DATASET_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -557,7 +558,7 @@ static const yytype_int8 yytranslate[] =
        5,     6,     7,     8,     9,    10,    11,    12,    13,    14
 };
 
-#if YYDEBUG
+#if DATASET_DEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
@@ -569,7 +570,7 @@ static const yytype_uint8 yyrline[] =
 /** Accessing symbol of state STATE.  */
 #define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])
 
-#if YYDEBUG || 0
+#if DATASET_DEBUG || 0
 /* The user-facing name of the symbol whose (internal) number is
    YYSYMBOL.  No bounds checking.  */
 static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;
@@ -682,7 +683,7 @@ static const yytype_int8 yyr2[] =
 enum { YYENOMEM = -2 };
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (yychar = YYEMPTY)
+#define yyclearin       (yychar = DATASET_EMPTY)
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
@@ -694,7 +695,7 @@ enum { YYENOMEM = -2 };
 
 #define YYBACKUP(Token, Value)                                    \
   do                                                              \
-    if (yychar == YYEMPTY)                                        \
+    if (yychar == DATASET_EMPTY)                                        \
       {                                                           \
         yychar = (Token);                                         \
         yylval = (Value);                                         \
@@ -710,12 +711,12 @@ enum { YYENOMEM = -2 };
   while (0)
 
 /* Backward compatibility with an undocumented macro.
-   Use YYerror or YYUNDEF. */
-#define YYERRCODE YYUNDEF
+   Use DATASET_error or DATASET_UNDEF. */
+#define YYERRCODE DATASET_UNDEF
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if DATASET_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -833,12 +834,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !DATASET_DEBUG */
 # define YYDPRINTF(Args) ((void) 0)
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !DATASET_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -938,7 +939,7 @@ yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = DATASET_EMPTY; /* Cause a token to be read.  */
 
   goto yysetstate;
 
@@ -1048,25 +1049,25 @@ yybackup:
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
-  if (yychar == YYEMPTY)
+  if (yychar == DATASET_EMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token\n"));
       yychar = yylex ();
     }
 
-  if (yychar <= YYEOF)
+  if (yychar <= DATASET_EOF)
     {
-      yychar = YYEOF;
+      yychar = DATASET_EOF;
       yytoken = YYSYMBOL_YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
-  else if (yychar == YYerror)
+  else if (yychar == DATASET_error)
     {
       /* The scanner already issued an error message, process directly
          to error recovery.  But do not keep the error token as
          lookahead, it is too special and may lead us to an endless
          loop in error recovery. */
-      yychar = YYUNDEF;
+      yychar = DATASET_UNDEF;
       yytoken = YYSYMBOL_YYerror;
       goto yyerrlab1;
     }
@@ -1103,7 +1104,7 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  yychar = DATASET_EMPTY;
   goto yynewstate;
 
 
@@ -1139,39 +1140,39 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* Input: VersionLine VariableList  */
-#line 91 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 91 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                            { /* describes a valid dataset */ }
-#line 1145 "parse_dataset.cpp"
+#line 1146 "parse_dataset.cpp"
     break;
 
   case 3: /* VersionLine: Version Eol  */
-#line 95 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 95 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
               { /* version line */
     (yyval.data) = dataset_result = new dataset ();
   }
-#line 1153 "parse_dataset.cpp"
+#line 1154 "parse_dataset.cpp"
     break;
 
   case 4: /* VariableList: %empty  */
-#line 100 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 100 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                             { }
-#line 1159 "parse_dataset.cpp"
+#line 1160 "parse_dataset.cpp"
     break;
 
   case 5: /* VariableList: Variable VariableList  */
-#line 101 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 101 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                           { /* dependent and independent variable vectors */ }
-#line 1165 "parse_dataset.cpp"
+#line 1166 "parse_dataset.cpp"
     break;
 
   case 6: /* VariableList: Eol VariableList  */
-#line 102 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 102 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                           { /* skip to next line */ }
-#line 1171 "parse_dataset.cpp"
+#line 1172 "parse_dataset.cpp"
     break;
 
   case 7: /* Variable: '<' DepBegin Identifier IdentifierList '>' FloatList '<' DepEnd '>'  */
-#line 106 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 106 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                                                                       {
     /* dependent variable vector */
     dataset_vector->setName ((yyvsp[-6].ident));
@@ -1182,11 +1183,11 @@ yyreduce:
     dataset_idents = NULL;
     free ((yyvsp[-6].ident));
   }
-#line 1186 "parse_dataset.cpp"
+#line 1187 "parse_dataset.cpp"
     break;
 
   case 8: /* Variable: '<' IndepBegin Identifier Integer '>' FloatList '<' IndepEnd '>'  */
-#line 116 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 116 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                                                                      {
     /* independent variable vector */
     dataset_vector->setRequested ((yyvsp[-5].n));
@@ -1196,62 +1197,62 @@ yyreduce:
     dataset_vector = NULL;
     free ((yyvsp[-6].ident));
   }
-#line 1200 "parse_dataset.cpp"
+#line 1201 "parse_dataset.cpp"
     break;
 
   case 9: /* FloatList: %empty  */
-#line 127 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 127 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                          { (yyval.v) = dataset_vector = new vector (); }
-#line 1206 "parse_dataset.cpp"
+#line 1207 "parse_dataset.cpp"
     break;
 
   case 10: /* FloatList: REAL FloatList  */
-#line 128 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 128 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                    {
     dataset_vector->add ((yyvsp[-1].f));
   }
-#line 1214 "parse_dataset.cpp"
+#line 1215 "parse_dataset.cpp"
     break;
 
   case 11: /* FloatList: COMPLEX FloatList  */
-#line 131 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 131 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                       {
     dataset_vector->add (nr_complex_t ((yyvsp[-1].c).r, (yyvsp[-1].c).i));
   }
-#line 1222 "parse_dataset.cpp"
+#line 1223 "parse_dataset.cpp"
     break;
 
   case 12: /* FloatList: IMAG FloatList  */
-#line 134 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 134 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                    {
     dataset_vector->add (nr_complex_t (0.0, (yyvsp[-1].f)));
   }
-#line 1230 "parse_dataset.cpp"
+#line 1231 "parse_dataset.cpp"
     break;
 
   case 13: /* FloatList: Eol FloatList  */
-#line 137 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 137 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                   { /* skip to next line */ }
-#line 1236 "parse_dataset.cpp"
+#line 1237 "parse_dataset.cpp"
     break;
 
   case 14: /* IdentifierList: %empty  */
-#line 140 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 140 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                               { (yyval.list) = dataset_idents = new strlist (); }
-#line 1242 "parse_dataset.cpp"
+#line 1243 "parse_dataset.cpp"
     break;
 
   case 15: /* IdentifierList: Identifier IdentifierList  */
-#line 141 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 141 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
                               {
     dataset_idents->add ((yyvsp[-1].ident));
     free ((yyvsp[-1].ident));
   }
-#line 1251 "parse_dataset.cpp"
+#line 1252 "parse_dataset.cpp"
     break;
 
 
-#line 1255 "parse_dataset.cpp"
+#line 1256 "parse_dataset.cpp"
 
       default: break;
     }
@@ -1293,7 +1294,7 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
+  yytoken = yychar == DATASET_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
@@ -1306,17 +1307,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (yychar <= YYEOF)
+      if (yychar <= DATASET_EOF)
         {
           /* Return failure if at end of input.  */
-          if (yychar == YYEOF)
+          if (yychar == DATASET_EOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
                       yytoken, &yylval);
-          yychar = YYEMPTY;
+          yychar = DATASET_EMPTY;
         }
     }
 
@@ -1418,7 +1419,7 @@ yyexhaustedlab:
 | yyreturnlab -- parsing is finished, clean up and return.  |
 `----------------------------------------------------------*/
 yyreturnlab:
-  if (yychar != YYEMPTY)
+  if (yychar != DATASET_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
@@ -1444,7 +1445,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 147 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_dataset.ypp"
+#line 147 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_dataset.ypp"
 
 
 int dataset_error (const char * error) {
