@@ -63,7 +63,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         TOUCHSTONE_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         touchstone_parse
 #define yylex           touchstone_lex
@@ -74,7 +75,7 @@
 #define yychar          touchstone_char
 
 /* First part of user prologue.  */
-#line 3 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
 
 /*
  * parse_touchstone.y - parser for Touchstone files
@@ -123,7 +124,7 @@
 using namespace qucs;
 
 
-#line 127 "parse_touchstone.cpp"
+#line 128 "parse_touchstone.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -432,7 +433,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined TOUCHSTONE_STYPE_IS_TRIVIAL && TOUCHSTONE_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -548,7 +549,7 @@ static const yytype_int8 yytranslate[] =
        5,     6
 };
 
-#if YYDEBUG
+#if TOUCHSTONE_DEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
@@ -560,7 +561,7 @@ static const yytype_uint8 yyrline[] =
 /** Accessing symbol of state STATE.  */
 #define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])
 
-#if YYDEBUG || 0
+#if TOUCHSTONE_DEBUG || 0
 /* The user-facing name of the symbol whose (internal) number is
    YYSYMBOL.  No bounds checking.  */
 static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;
@@ -666,7 +667,7 @@ static const yytype_int8 yyr2[] =
 enum { YYENOMEM = -2 };
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (yychar = YYEMPTY)
+#define yyclearin       (yychar = TOUCHSTONE_EMPTY)
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
@@ -678,7 +679,7 @@ enum { YYENOMEM = -2 };
 
 #define YYBACKUP(Token, Value)                                    \
   do                                                              \
-    if (yychar == YYEMPTY)                                        \
+    if (yychar == TOUCHSTONE_EMPTY)                                        \
       {                                                           \
         yychar = (Token);                                         \
         yylval = (Value);                                         \
@@ -694,12 +695,12 @@ enum { YYENOMEM = -2 };
   while (0)
 
 /* Backward compatibility with an undocumented macro.
-   Use YYerror or YYUNDEF. */
-#define YYERRCODE YYUNDEF
+   Use TOUCHSTONE_error or TOUCHSTONE_UNDEF. */
+#define YYERRCODE TOUCHSTONE_UNDEF
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if TOUCHSTONE_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -817,12 +818,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !TOUCHSTONE_DEBUG */
 # define YYDPRINTF(Args) ((void) 0)
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !TOUCHSTONE_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -922,7 +923,7 @@ yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = TOUCHSTONE_EMPTY; /* Cause a token to be read.  */
 
   goto yysetstate;
 
@@ -1032,25 +1033,25 @@ yybackup:
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
-  if (yychar == YYEMPTY)
+  if (yychar == TOUCHSTONE_EMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token\n"));
       yychar = yylex ();
     }
 
-  if (yychar <= YYEOF)
+  if (yychar <= TOUCHSTONE_EOF)
     {
-      yychar = YYEOF;
+      yychar = TOUCHSTONE_EOF;
       yytoken = YYSYMBOL_YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
-  else if (yychar == YYerror)
+  else if (yychar == TOUCHSTONE_error)
     {
       /* The scanner already issued an error message, process directly
          to error recovery.  But do not keep the error token as
          lookahead, it is too special and may lead us to an endless
          loop in error recovery. */
-      yychar = YYUNDEF;
+      yychar = TOUCHSTONE_UNDEF;
       yytoken = YYSYMBOL_YYerror;
       goto yyerrlab1;
     }
@@ -1087,7 +1088,7 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  yychar = TOUCHSTONE_EMPTY;
   goto yynewstate;
 
 
@@ -1123,59 +1124,59 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* Input: OptionLine Dataset  */
-#line 74 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 74 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                      { /* describes a valid touchstone */ }
-#line 1129 "parse_touchstone.cpp"
+#line 1130 "parse_touchstone.cpp"
     break;
 
   case 3: /* OptionLine: '#' OptionList 'R' Float OptionList Eol  */
-#line 78 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 78 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                                             {
     touchstone_line = NULL;
     touchstone_options.resistance = (yyvsp[-2].f);
   }
-#line 1138 "parse_touchstone.cpp"
+#line 1139 "parse_touchstone.cpp"
     break;
 
   case 4: /* OptionLine: '#' OptionList Eol  */
-#line 82 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 82 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                        {
     touchstone_line = NULL;
     touchstone_options.resistance = 50.0;
   }
-#line 1147 "parse_touchstone.cpp"
+#line 1148 "parse_touchstone.cpp"
     break;
 
   case 5: /* OptionLine: Eol OptionLine  */
-#line 86 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 86 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                    { /* skip this line */ }
-#line 1153 "parse_touchstone.cpp"
+#line 1154 "parse_touchstone.cpp"
     break;
 
   case 6: /* OptionList: %empty  */
-#line 89 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 89 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                           { }
-#line 1159 "parse_touchstone.cpp"
+#line 1160 "parse_touchstone.cpp"
     break;
 
   case 7: /* OptionList: OptionList Option  */
-#line 90 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 90 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                       {
     if (touchstone_idents == NULL) touchstone_idents = new strlist ();
     touchstone_idents->add ((yyvsp[0].ident));
     free ((yyvsp[0].ident));
   }
-#line 1169 "parse_touchstone.cpp"
+#line 1170 "parse_touchstone.cpp"
     break;
 
   case 8: /* Dataset: %empty  */
-#line 97 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 97 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                        { }
-#line 1175 "parse_touchstone.cpp"
+#line 1176 "parse_touchstone.cpp"
     break;
 
   case 9: /* Dataset: Dataset DataLine Eol  */
-#line 98 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 98 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                          { /* append vector lines */
     if (!touchstone_vector)
       touchstone_vector = (yyvsp[-1].v); /* save first vector location */
@@ -1183,11 +1184,11 @@ yyreduce:
       touchstone_line->setNext((yyvsp[-1].v));
     touchstone_line = (yyvsp[-1].v);
   }
-#line 1187 "parse_touchstone.cpp"
+#line 1188 "parse_touchstone.cpp"
     break;
 
   case 10: /* Dataset: Dataset DataLine  */
-#line 105 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 105 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                      { /* last line, no trailing end-of-line */
     if (!touchstone_vector)
       touchstone_vector = (yyvsp[0].v); /* save first vector location */
@@ -1197,17 +1198,17 @@ yyreduce:
     logprint (LOG_ERROR, "line %d: no trailing end-of-line found, "
 	      "continuing...\n", touchstone_lineno);
   }
-#line 1201 "parse_touchstone.cpp"
+#line 1202 "parse_touchstone.cpp"
     break;
 
   case 11: /* Dataset: Dataset Eol  */
-#line 114 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 114 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                 { /* skip this line */ }
-#line 1207 "parse_touchstone.cpp"
+#line 1208 "parse_touchstone.cpp"
     break;
 
   case 12: /* DataLine: Float Float Float  */
-#line 118 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 118 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                       {
     /* 1-port start */
     (yyval.v) = new vector ();
@@ -1215,11 +1216,11 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1219 "parse_touchstone.cpp"
+#line 1220 "parse_touchstone.cpp"
     break;
 
   case 13: /* DataLine: Float Float Float Float Float  */
-#line 125 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 125 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                                   {
     /* noise parameters */
     (yyval.v) = new vector ();
@@ -1229,11 +1230,11 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1233 "parse_touchstone.cpp"
+#line 1234 "parse_touchstone.cpp"
     break;
 
   case 14: /* DataLine: Float Float Float Float Float Float Float Float Float  */
-#line 134 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 134 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                                                           {
     /* 2-port and 4- to n-port start */
     (yyval.v) = new vector ();
@@ -1247,11 +1248,11 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1251 "parse_touchstone.cpp"
+#line 1252 "parse_touchstone.cpp"
     break;
 
   case 15: /* DataLine: Float Float Float Float Float Float Float  */
-#line 147 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 147 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                                               {
     /* 3-port start */
     (yyval.v) = new vector ();
@@ -1263,11 +1264,11 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1267 "parse_touchstone.cpp"
+#line 1268 "parse_touchstone.cpp"
     break;
 
   case 16: /* DataLine: Float Float Float Float Float Float Float Float  */
-#line 158 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 158 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                                                     {
     /* 4- and n-port continued */
     (yyval.v) = new vector ();
@@ -1280,11 +1281,11 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1284 "parse_touchstone.cpp"
+#line 1285 "parse_touchstone.cpp"
     break;
 
   case 17: /* DataLine: Float Float Float Float Float Float  */
-#line 170 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 170 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                                         {
     /* 3- and n-port continued */
     (yyval.v) = new vector ();
@@ -1295,11 +1296,11 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1299 "parse_touchstone.cpp"
+#line 1300 "parse_touchstone.cpp"
     break;
 
   case 18: /* DataLine: Float Float Float Float  */
-#line 180 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 180 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                             {
     /* n-port continued */
     (yyval.v) = new vector ();
@@ -1308,22 +1309,22 @@ yyreduce:
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1312 "parse_touchstone.cpp"
+#line 1313 "parse_touchstone.cpp"
     break;
 
   case 19: /* DataLine: Float Float  */
-#line 188 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 188 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
                 {
     /* n-port continued */
     (yyval.v) = new vector ();
     (yyval.v)->add ((yyvsp[-1].f));
     (yyval.v)->add ((yyvsp[0].f));
   }
-#line 1323 "parse_touchstone.cpp"
+#line 1324 "parse_touchstone.cpp"
     break;
 
 
-#line 1327 "parse_touchstone.cpp"
+#line 1328 "parse_touchstone.cpp"
 
       default: break;
     }
@@ -1365,7 +1366,7 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
+  yytoken = yychar == TOUCHSTONE_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
@@ -1378,17 +1379,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (yychar <= YYEOF)
+      if (yychar <= TOUCHSTONE_EOF)
         {
           /* Return failure if at end of input.  */
-          if (yychar == YYEOF)
+          if (yychar == TOUCHSTONE_EOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
                       yytoken, &yylval);
-          yychar = YYEMPTY;
+          yychar = TOUCHSTONE_EMPTY;
         }
     }
 
@@ -1490,7 +1491,7 @@ yyexhaustedlab:
 | yyreturnlab -- parsing is finished, clean up and return.  |
 `----------------------------------------------------------*/
 yyreturnlab:
-  if (yychar != YYEMPTY)
+  if (yychar != TOUCHSTONE_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
@@ -1516,7 +1517,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 196 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_touchstone.ypp"
+#line 196 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_touchstone.ypp"
 
 
 int touchstone_error (const char * error) {
