@@ -63,7 +63,8 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-
+/* Substitute the type names.  */
+#define YYSTYPE         ZVR_STYPE
 /* Substitute the variable and function names.  */
 #define yyparse         zvr_parse
 #define yylex           zvr_lex
@@ -74,7 +75,7 @@
 #define yychar          zvr_char
 
 /* First part of user prologue.  */
-#line 3 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 3 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
 
 /*
  * parse_zvr.y - parser for a ZVR data file
@@ -123,7 +124,7 @@
 using namespace qucs;
 
 
-#line 127 "parse_zvr.cpp"
+#line 128 "parse_zvr.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -443,7 +444,7 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 
 #if (! defined yyoverflow \
      && (! defined __cplusplus \
-         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))
+         || (defined ZVR_STYPE_IS_TRIVIAL && ZVR_STYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
@@ -559,7 +560,7 @@ static const yytype_int8 yytranslate[] =
        5,     6,     7,     8,     9,    10,    11
 };
 
-#if YYDEBUG
+#if ZVR_DEBUG
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
@@ -571,7 +572,7 @@ static const yytype_uint8 yyrline[] =
 /** Accessing symbol of state STATE.  */
 #define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])
 
-#if YYDEBUG || 0
+#if ZVR_DEBUG || 0
 /* The user-facing name of the symbol whose (internal) number is
    YYSYMBOL.  No bounds checking.  */
 static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;
@@ -704,7 +705,7 @@ static const yytype_int8 yyr2[] =
 enum { YYENOMEM = -2 };
 
 #define yyerrok         (yyerrstatus = 0)
-#define yyclearin       (yychar = YYEMPTY)
+#define yyclearin       (yychar = ZVR_EMPTY)
 
 #define YYACCEPT        goto yyacceptlab
 #define YYABORT         goto yyabortlab
@@ -716,7 +717,7 @@ enum { YYENOMEM = -2 };
 
 #define YYBACKUP(Token, Value)                                    \
   do                                                              \
-    if (yychar == YYEMPTY)                                        \
+    if (yychar == ZVR_EMPTY)                                        \
       {                                                           \
         yychar = (Token);                                         \
         yylval = (Value);                                         \
@@ -732,12 +733,12 @@ enum { YYENOMEM = -2 };
   while (0)
 
 /* Backward compatibility with an undocumented macro.
-   Use YYerror or YYUNDEF. */
-#define YYERRCODE YYUNDEF
+   Use ZVR_error or ZVR_UNDEF. */
+#define YYERRCODE ZVR_UNDEF
 
 
 /* Enable debugging if requested.  */
-#if YYDEBUG
+#if ZVR_DEBUG
 
 # ifndef YYFPRINTF
 #  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
@@ -855,12 +856,12 @@ do {                                    \
 /* Nonzero means print parse trace.  It is left uninitialized so that
    multiple parsers can coexist.  */
 int yydebug;
-#else /* !YYDEBUG */
+#else /* !ZVR_DEBUG */
 # define YYDPRINTF(Args) ((void) 0)
 # define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
-#endif /* !YYDEBUG */
+#endif /* !ZVR_DEBUG */
 
 
 /* YYINITDEPTH -- initial size of the parser's stacks.  */
@@ -960,7 +961,7 @@ yyparse (void)
 
   YYDPRINTF ((stderr, "Starting parse\n"));
 
-  yychar = YYEMPTY; /* Cause a token to be read.  */
+  yychar = ZVR_EMPTY; /* Cause a token to be read.  */
 
   goto yysetstate;
 
@@ -1070,25 +1071,25 @@ yybackup:
   /* Not known => get a lookahead token if don't already have one.  */
 
   /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
-  if (yychar == YYEMPTY)
+  if (yychar == ZVR_EMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token\n"));
       yychar = yylex ();
     }
 
-  if (yychar <= YYEOF)
+  if (yychar <= ZVR_EOF)
     {
-      yychar = YYEOF;
+      yychar = ZVR_EOF;
       yytoken = YYSYMBOL_YYEOF;
       YYDPRINTF ((stderr, "Now at end of input.\n"));
     }
-  else if (yychar == YYerror)
+  else if (yychar == ZVR_error)
     {
       /* The scanner already issued an error message, process directly
          to error recovery.  But do not keep the error token as
          lookahead, it is too special and may lead us to an endless
          loop in error recovery. */
-      yychar = YYUNDEF;
+      yychar = ZVR_UNDEF;
       yytoken = YYSYMBOL_YYerror;
       goto yyerrlab1;
     }
@@ -1125,7 +1126,7 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   /* Discard the shifted token.  */
-  yychar = YYEMPTY;
+  yychar = ZVR_EMPTY;
   goto yynewstate;
 
 
@@ -1161,28 +1162,28 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* Input: Header Body BodyList  */
-#line 82 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 82 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                        { /* a ZVR file */
     (yyvsp[-1].data)->next = (yyvsp[0].data);
     zvr_root = (yyvsp[-1].data);
   }
-#line 1170 "parse_zvr.cpp"
+#line 1171 "parse_zvr.cpp"
     break;
 
   case 3: /* Header: ZVR Version  */
-#line 89 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 89 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
               { }
-#line 1176 "parse_zvr.cpp"
+#line 1177 "parse_zvr.cpp"
     break;
 
   case 4: /* BodyList: %empty  */
-#line 92 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 92 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                         { (yyval.data) = NULL; }
-#line 1182 "parse_zvr.cpp"
+#line 1183 "parse_zvr.cpp"
     break;
 
   case 5: /* BodyList: Body BodyList  */
-#line 93 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 93 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                   {
     if ((yyvsp[-1].data)) {
       (yyvsp[-1].data)->next = (yyvsp[0].data);
@@ -1191,25 +1192,25 @@ yyreduce:
       (yyval.data) = (yyvsp[0].data);
     }
   }
-#line 1195 "parse_zvr.cpp"
+#line 1196 "parse_zvr.cpp"
     break;
 
   case 6: /* ParaList6: Identifier ';' Identifier ';' Identifier ';' Identifier ';' Identifier ';' Identifier  */
-#line 105 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 105 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                                            {
   }
-#line 1202 "parse_zvr.cpp"
+#line 1203 "parse_zvr.cpp"
     break;
 
   case 7: /* ParaList2: Identifier ';' Identifier  */
-#line 110 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 110 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                             {
   }
-#line 1209 "parse_zvr.cpp"
+#line 1210 "parse_zvr.cpp"
     break;
 
   case 10: /* BodyStart: ParaList6 Real ';' Real ';' Unit ';' Real ';' DataTYP ';' Real ParaList6 DataTYP ';' Ident ';' DataFMT ';' Ident ';' Ident ';' Ident ParaList2 Ident ';' Ident  */
-#line 124 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 124 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                     {
     (yyval.head) = (struct zvr_header_t *) calloc (sizeof (struct zvr_header_t), 1);
     (yyval.head)->start = (yyvsp[-26].f);
@@ -1221,28 +1222,28 @@ yyreduce:
     (yyval.head)->d_UNT = (yyvsp[-8].ident);
     (yyval.head)->d_FMT = (yyvsp[-10].ident);
   }
-#line 1225 "parse_zvr.cpp"
+#line 1226 "parse_zvr.cpp"
     break;
 
   case 11: /* Body: BodyStart DataHeader DataList  */
-#line 138 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 138 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                                 {
     (yyval.data) = (struct zvr_data_t *) calloc (sizeof (struct zvr_data_t), 1);
     (yyval.data)->h = (yyvsp[-2].head);
     (yyval.data)->v = (yyvsp[-1].vec);
     (yyval.data)->d = (yyvsp[0].line);
   }
-#line 1236 "parse_zvr.cpp"
+#line 1237 "parse_zvr.cpp"
     break;
 
   case 12: /* DataList: %empty  */
-#line 146 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 146 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                         { (yyval.line) = NULL; }
-#line 1242 "parse_zvr.cpp"
+#line 1243 "parse_zvr.cpp"
     break;
 
   case 13: /* DataList: DataLine DataList  */
-#line 147 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 147 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                       {
     if ((yyvsp[-1].line)) {
       (yyvsp[-1].line)->next = (yyvsp[0].line);
@@ -1251,32 +1252,32 @@ yyreduce:
       (yyval.line) = (yyvsp[0].line);
     }
   }
-#line 1255 "parse_zvr.cpp"
+#line 1256 "parse_zvr.cpp"
     break;
 
   case 14: /* DataLine: Real ';' Real  */
-#line 158 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 158 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                 {
     (yyval.line) = (struct zvr_line_t *) calloc (sizeof (struct zvr_line_t), 1);
     (yyval.line)->d = (yyvsp[-2].f);
     (yyval.line)->r = (yyvsp[0].f);
   }
-#line 1265 "parse_zvr.cpp"
+#line 1266 "parse_zvr.cpp"
     break;
 
   case 15: /* DataLine: Real ';' Real ';' Real  */
-#line 163 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 163 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                            {
     (yyval.line) = (struct zvr_line_t *) calloc (sizeof (struct zvr_line_t), 1);
     (yyval.line)->d = (yyvsp[-4].f);
     (yyval.line)->r = (yyvsp[-2].f);
     (yyval.line)->i = (yyvsp[0].f);
   }
-#line 1276 "parse_zvr.cpp"
+#line 1277 "parse_zvr.cpp"
     break;
 
   case 18: /* DataHeader: Identifier ';' DataIdent  */
-#line 176 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 176 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                            {
     (yyval.vec) = (struct zvr_vector_t *) calloc (sizeof (struct zvr_vector_t), 1);
     (yyval.vec)->nf = (yyvsp[-2].ident);
@@ -1284,11 +1285,11 @@ yyreduce:
     (yyval.vec)->vi = new vector ();
     (yyval.vec)->vd = new vector ();
   }
-#line 1288 "parse_zvr.cpp"
+#line 1289 "parse_zvr.cpp"
     break;
 
   case 19: /* DataHeader: Identifier ';' DataIdent ';' DataIdent  */
-#line 183 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 183 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
                                            {
     (yyval.vec) = (struct zvr_vector_t *) calloc (sizeof (struct zvr_vector_t), 1);
     (yyval.vec)->nf = (yyvsp[-4].ident);
@@ -1297,11 +1298,11 @@ yyreduce:
     (yyval.vec)->vi = new vector ();
     (yyval.vec)->vd = new vector ();
   }
-#line 1301 "parse_zvr.cpp"
+#line 1302 "parse_zvr.cpp"
     break;
 
 
-#line 1305 "parse_zvr.cpp"
+#line 1306 "parse_zvr.cpp"
 
       default: break;
     }
@@ -1343,7 +1344,7 @@ yyreduce:
 yyerrlab:
   /* Make sure we have latest lookahead translation.  See comments at
      user semantic actions for why this is necessary.  */
-  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
+  yytoken = yychar == ZVR_EMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
   /* If not already recovering from an error, report this error.  */
   if (!yyerrstatus)
     {
@@ -1356,17 +1357,17 @@ yyerrlab:
       /* If just tried and failed to reuse lookahead token after an
          error, discard it.  */
 
-      if (yychar <= YYEOF)
+      if (yychar <= ZVR_EOF)
         {
           /* Return failure if at end of input.  */
-          if (yychar == YYEOF)
+          if (yychar == ZVR_EOF)
             YYABORT;
         }
       else
         {
           yydestruct ("Error: discarding",
                       yytoken, &yylval);
-          yychar = YYEMPTY;
+          yychar = ZVR_EMPTY;
         }
     }
 
@@ -1468,7 +1469,7 @@ yyexhaustedlab:
 | yyreturnlab -- parsing is finished, clean up and return.  |
 `----------------------------------------------------------*/
 yyreturnlab:
-  if (yychar != YYEMPTY)
+  if (yychar != ZVR_EMPTY)
     {
       /* Make sure we have latest lookahead translation.  See comments at
          user semantic actions for why this is necessary.  */
@@ -1494,7 +1495,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 193 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_zvr.ypp"
+#line 193 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_zvr.ypp"
 
 
 int zvr_error (const char * error) {
