@@ -89,22 +89,21 @@ Element* iPulse::info(QString& Name, char* &BitmapFile, bool getNewOne)
   return 0;
 }
 
-QString iPulse::spice_netlist(bool)
+QString iPulse::spice_netlist(spicecompat::SpiceDialect dialect /* = spicecompat::SPICEDefault */)
 {
+    Q_UNUSED(dialect);
+
     QString s = spicecompat::check_refdes(Name,SpiceModel);
 
-    for (Port *p1 : Ports) {
-        QString nam = p1->Connection->Name;
-        if (nam=="gnd") nam = "0";
-        s += " "+ nam;   // node names
-    }
+    s += " " + spicecompat::normalize_node_name(Ports.at(1)->Connection->Name);
+    s += " " + spicecompat::normalize_node_name(Ports.at(0)->Connection->Name);
 
     double T1,T2, TrVal, TfVal, Pw,fac,Per;
     QString unit;
 
     QString VL = spicecompat::normalize_value(Props.at(0)->Value); // VL
     QString VH = spicecompat::normalize_value(Props.at(1)->Value); // VH
-   QString Tr = spicecompat::normalize_value(Props.at(4)->Value); // Tr 
+    QString Tr = spicecompat::normalize_value(Props.at(4)->Value); // Tr 
     QString Tf = spicecompat::normalize_value(Props.at(5)->Value); // Tf
 
     misc::str2num(Props.at(2)->Value,T1,unit,fac); // Td
@@ -117,7 +116,7 @@ QString iPulse::spice_netlist(bool)
     Pw = Pw - TfVal*fac;
     Per = 1.0e9*Pw;
 
-    s += QString(" DC 0 PULSE(%1 %2 %3 %4 %5 %6 %7) AC 0\n").arg(VL).arg(VH).arg(T1).arg(Tr).arg(Tf).arg(Pw).arg(Per);
+    s += QStringLiteral(" DC 0 PULSE(%1 %2 %3 %4 %5 %6 %7) AC 0\n").arg(VL).arg(VH).arg(T1).arg(Tr).arg(Tf).arg(Pw).arg(Per);
 
     return s;
 }
